==> apache-camel-3.2.0-src.zip: apache-camel-3.2.0/core/camel-core/src/test/java/org/apache/camel/impl/GetRegistryAsTypeTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.impl;

import java.util.Map;

import org.apache.camel.CamelContext;
import org.apache.camel.support.DefaultRegistry;
import org.apache.camel.support.SimpleRegistry;
import org.apache.camel.support.jndi.JndiBeanRepository;
import org.junit.Assert;
import org.junit.Test;

public class GetRegistryAsTypeTest extends Assert {

    @Test
    public void testDefault() throws Exception {
        CamelContext context = new DefaultCamelContext();
        context.start();

        assertNotNull(context.getRegistry(DefaultRegistry.class));
        assertNotNull(context.getRegistry());

        assertNull(context.getRegistry(Map.class));
        assertNull(context.getRegistry(JndiBeanRepository.class));
        assertNull(context.getRegistry(SimpleRegistry.class));

        context.stop();
    }

    @Test
    public void testSimple() throws Exception {
        CamelContext context = new DefaultCamelContext(new SimpleRegistry());
        context.start();

        SimpleRegistry simple = context.getRegistry(SimpleRegistry.class);
        assertNotNull(simple);

        // simple extends Map
        assertNotNull(context.getRegistry(Map.class));
        assertNull(context.getRegistry(JndiBeanRepository.class));

        context.stop();
    }

}

==> apache-camel-4.10.8-src.zip: apache-camel-4.10.8/core/camel-core/src/test/java/org/apache/camel/impl/GetRegistryAsTypeTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.impl;

import java.util.Map;

import org.apache.camel.CamelContext;
import org.apache.camel.support.DefaultRegistry;
import org.apache.camel.support.SimpleRegistry;
import org.apache.camel.support.jndi.JndiBeanRepository;
import org.junit.jupiter.api.Test;

import static org.junit.jupiter.api.Assertions.assertNotNull;
import static org.junit.jupiter.api.Assertions.assertNull;

public class GetRegistryAsTypeTest {

    @Test
    public void testDefault() {
        CamelContext context = new DefaultCamelContext();
        context.start();

        assertNotNull(context.getRegistry(DefaultRegistry.class));
        assertNotNull(context.getRegistry());

        assertNull(context.getRegistry(Map.class));
        assertNull(context.getRegistry(JndiBeanRepository.class));
        assertNull(context.getRegistry(SimpleRegistry.class));

        context.stop();
    }

    @Test
    public void testSimple() {
        CamelContext context = new DefaultCamelContext(new SimpleRegistry());
        context.start();

        SimpleRegistry simple = context.getRegistry(SimpleRegistry.class);
        assertNotNull(simple);

        // simple extends Map
        assertNotNull(context.getRegistry(Map.class));
        assertNull(context.getRegistry(JndiBeanRepository.class));

        context.stop();
    }

}
